===
API
===

.. _xsdba-user-api:

xsdba Module
============

.. automodule:: xsdba.adjustment
   :members:
   :exclude-members: BaseAdjustment
   :special-members:
   :show-inheritance:
   :noindex:

.. automodule:: xsdba.processing
   :members:
   :noindex:

.. automodule:: xsdba.detrending
   :members:
   :show-inheritance:
   :exclude-members: BaseDetrend
   :noindex:

.. automodule:: xsdba.utils
   :members:
   :noindex:

.. autoclass:: xsdba.base.Grouper
   :members:
   :class-doc-from: init
   :noindex:

.. automodule:: xsdba.nbutils
   :members:
   :noindex:

.. automodule:: xsdba.loess
   :members:
   :noindex:

.. automodule:: xsdba.properties
   :members:
   :exclude-members: StatisticalProperty
   :noindex:

.. automodule:: xsdba.measures
   :members:
   :exclude-members: StatisticalMeasure
   :noindex:

.. _`xsdba-developer-api`:

xsdba Utilities
---------------

.. automodule:: xsdba.base
   :members:
   :show-inheritance:
   :exclude-members: Grouper
   :noindex:

.. autoclass:: xsdba.detrending.BaseDetrend
   :members:
   :noindex:

.. autoclass:: xsdba.adjustment.TrainAdjust
   :members:
   :noindex:

.. autoclass:: xsdba.adjustment.Adjust
   :members:
   :noindex:

.. autofunction:: xsdba.properties.StatisticalProperty
   :noindex:

.. autofunction:: xsdba.measures.StatisticalMeasure
   :noindex:
